@@ -1,15 +1,30 @@
-from typing import List, Literal, Optional
+from typing import Any, List, Literal, Optional, Sequence
 
 from pandas import DataFrame, concat
 from pydantic import Field, root_validator
 from pydantic.main import BaseModel
 
+from weaverbird.render_variables import StepWithVariablesMixin
 from weaverbird.steps.base import BaseStep
-from weaverbird.types import ColumnName, PopulatedWithFieldnames
+from weaverbird.types import ColumnName, PopulatedWithFieldnames, TemplatedVariable
 
-AggregateFn = Literal['avg', 'sum', 'min', 'max', 'count', 'first', 'last']
+AggregateFn = Literal[
+    'avg',
+    'sum',
+    'min',
+    'max',
+    'count',
+    'count distinct',
+    'first',
+    'last',
+    'count distinct including empty',
+]
 
-functions_aliases = {'avg': 'mean'}
+functions_aliases = {
+    'avg': 'mean',
+    'count distinct': 'nunique',
+    'count distinct including empty': len,
+}
 
 
 class Aggregation(BaseModel):
@@ -29,7 +44,7 @@ class Aggregation(BaseModel):
         return values
 
 
-def get_aggregate_fn(agg_function: str) -> str:
+def get_aggregate_fn(agg_function: str) -> Any:
     if agg_function in functions_aliases:
         return functions_aliases[agg_function]
     return agg_function
@@ -45,7 +60,7 @@ def make_aggregation(aggregation: Aggregation) -> dict:
 class AggregateStep(BaseStep):
     name = Field('aggregate', const=True)
     on: List[ColumnName] = []
-    aggregations: List[Aggregation]
+    aggregations: Sequence[Aggregation]
     keep_original_granularity: Optional[bool] = Field(
         default=False, alias='keepOriginalGranularity'
     )
@@ -61,7 +76,7 @@ class AggregateStep(BaseStep):
             group_by_columns = ['__VQB__GROUP_BY__']
             df = df.assign(**{group_by_columns[0]: True})
 
-        grouped_by_df = df.groupby(group_by_columns)
+        grouped_by_df = df.groupby(group_by_columns, dropna=False)
         aggregated_cols = []
         for aggregation in self.aggregations:
             for col, new_col in zip(aggregation.columns, aggregation.new_columns):
@@ -82,3 +97,16 @@ class AggregateStep(BaseStep):
         if len(self.on) == 0:
             del df_result[group_by_columns[0]]
         return df_result
+
+
+class AggregationWithVariables(Aggregation):
+    class Config(PopulatedWithFieldnames):
+        ...
+
+    new_columns: List[TemplatedVariable] = Field(alias='newcolumns')
+    agg_function: TemplatedVariable = Field(alias='aggfunction')
+    columns: List[TemplatedVariable]
+
+
+class AggregateStepWithVariables(AggregateStep, StepWithVariablesMixin):
+    aggregations: Sequence[AggregationWithVariables]
