@@ -1,19 +1,20 @@
-from typing import List, Optional
+from typing import List, Optional, Sequence, Union
 
 from pandas import DataFrame, concat
 from pydantic import Field
 
+from weaverbird.render_variables import StepWithVariablesMixin
 from weaverbird.steps.base import BaseStep
-from weaverbird.types import ColumnName
+from weaverbird.types import ColumnName, TemplatedVariable
 
-from .aggregate import AggregateStep, Aggregation
+from .aggregate import AggregateStep, Aggregation, AggregationWithVariables
 
 
 class RollupStep(BaseStep):
     name = Field('rollup', const=True)
     hierarchy: List[ColumnName]
     # The list of columnns to aggregate, with related aggregation function to use:
-    aggregations: List[Aggregation]
+    aggregations: Sequence[Aggregation]
     # Groupby columns if rollup has to be performed by groups:
     groupby: Optional[List[ColumnName]]
     # To give a custom name to the output label column:
@@ -58,3 +59,9 @@ class RollupStep(BaseStep):
         )  # type: ignore
 
         return concat(all_results)[columns]
+
+
+class RollupStepWithVariable(RollupStep, StepWithVariablesMixin):
+    aggregations: Sequence[AggregationWithVariables]
+    hierarchy: Union[TemplatedVariable, List[TemplatedVariable]]
+    groupby: Union[TemplatedVariable, List[TemplatedVariable]]
