@@ -1,6 +1,7 @@
 import pandas as pd
 from pydantic import Field
 
+from weaverbird.render_variables import StepWithVariablesMixin
 from weaverbird.steps import BaseStep
 from weaverbird.types import ColumnName, DomainRetriever, PipelineExecutor
 
@@ -23,3 +24,7 @@ class SplitStep(BaseStep):
         for i in range(self.number_cols_to_keep):
             all_new_col[f'{self.column}_{i + 1}'] = new_serie.str[i]
         return df.assign(**all_new_col)
+
+
+class SplitStepWithVariable(SplitStep, StepWithVariablesMixin):
+    ...
