@@ -1,10 +1,11 @@
-from typing import List
+from typing import List, Union
 
 from pandas import DataFrame
 from pydantic import Field
 
+from weaverbird.render_variables import StepWithVariablesMixin
 from weaverbird.steps.base import BaseStep
-from weaverbird.types import ColumnName
+from weaverbird.types import ColumnName, TemplatedVariable
 
 
 class UniqueGroupsStep(BaseStep):
@@ -13,3 +14,7 @@ class UniqueGroupsStep(BaseStep):
 
     def execute(self, df: DataFrame, domain_retriever=None, execute_pipeline=None) -> DataFrame:
         return df[self.on].drop_duplicates()
+
+
+class UniqueGroupsStepWithVariable(UniqueGroupsStep, StepWithVariablesMixin):
+    on: Union[TemplatedVariable, List[TemplatedVariable]]
